summaryrefslogtreecommitdiffstats
path: root/src/knemod/interfacetooltip.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/knemod/interfacetooltip.h')
-rw-r--r--src/knemod/interfacetooltip.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/knemod/interfacetooltip.h b/src/knemod/interfacetooltip.h
index 7c4dbd9..c1dfada 100644
--- a/src/knemod/interfacetooltip.h
+++ b/src/knemod/interfacetooltip.h
@@ -20,28 +20,28 @@
#ifndef INTERFACETOOLTIP_H
#define INTERFACETOOLTIP_H
-#include <qpair.h>
-#include <qtooltip.h>
+#include <tqpair.h>
+#include <tqtooltip.h>
class Interface;
/**
* This call is responsible for displaying the tooltip of an
* interface icon. It is derived from QToolTip and overwrites
* the function maybeTip(const QPoint & p) to update the tooltip
* text just before it is going to be displayed.
*
* @short Display tooltip according to user settings
* @author Percy Leonhardt <percy@eris23.de>
*/
-class InterfaceToolTip : public QToolTip
+class InterfaceToolTip : public TQToolTip
{
public:
/**
* Default Constructor
*/
- InterfaceToolTip( Interface* interface, QWidget* parent = 0L );
+ InterfaceToolTip( Interface* interface, TQWidget* tqparent = 0L );
/**
* Default Destructor
@@ -49,24 +49,24 @@ public:
virtual ~InterfaceToolTip();
/**
- * From the Qt documentation:
+ * From the TQt documentation:
* It is called when there is a possibility that a tool tip should
* be shown and must decide whether there is a tool tip for the point p
* in the widget that this QToolTip object relates to. If so, maybeTip()
* must call tip() with the rectangle the tip applies to, the tip's text
* and optionally the QToolTipGroup details and the geometry in screen
* coordinates.
*/
- void maybeTip( const QPoint& );
+ void maybeTip( const TQPoint& );
private:
- void setupText( QString& text );
+ void setupText( TQString& text );
void setupToolTipArray();
// the interface this tooltip belongs to
Interface* mInterface;
// the tooltip text for each information
- QPair<QString, int> mToolTips[25];
+ TQPair<TQString, int> mToolTips[25];
};
#endif // INTERFACETOOLTIP_H
@@ -20,28 +20,28 @@
/**
* This call is responsible for displaying the tooltip of an
- * interface icon. It is derived from QToolTip and overwrites
- * the function maybeTip(const QPoint & p) to update the tooltip
+ * interface icon. It is derived from TQToolTip and overwrites
+ * the function maybeTip(const TQPoint & p) to update the tooltip
* text just before it is going to be displayed.
*
@@ -49,24 +49,24 @@ public:
* It is called when there is a possibility that a tool tip should
* be shown and must decide whether there is a tool tip for the point p
- * in the widget that this QToolTip object relates to. If so, maybeTip()
+ * in the widget that this TQToolTip object relates to. If so, maybeTip()
* must call tip() with the rectangle the tip applies to, the tip's text
@@ -49,24 +49,24 @@ public:
* must call tip() with the rectangle the tip applies to, the tip's text
- * and optionally the QToolTipGroup details and the geometry in screen
+ * and optionally the TQToolTipGroup details and the tqgeometry in screen
* coordinates.
*/